@@ -17,10 +17,14 @@ use Carp;
 sub new {
   my $this = shift;
 
-  Wx::_match( @_, $Wx::_wwin_wcur_wcur_wcur, 0, 1 ) && return $this->newCursorEmpty( @_ );
-  Wx::_match( @_, $Wx::_wdat_wwin_wcur_wcur_wcur, 1, 1 ) && return $this->newCursorData( @_ );
-  Wx::_match( @_, $Wx::_wwin_wico_wico_wico, 0, 1 ) && return $this->newIconEmpty( @_ );
-  Wx::_match( @_, $Wx::_wdat_wwin_wico_wico_wico, 1, 1 ) && return $this->newIconData( @_ );
+  if( $Wx::_platform != $Wx::_msw ) {
+    Wx::_match( @_, $Wx::_wwin_wico_wico_wico, 0, 1 ) && return $this->newIconEmpty( @_ );
+    Wx::_match( @_, $Wx::_wdat_wwin_wico_wico_wico, 1, 1 ) && return $this->newIconData( @_ );
+  } else {
+    Wx::_match( @_, $Wx::_wwin_wcur_wcur_wcur, 0, 1 ) && return $this->newCursorEmpty( @_ );
+    Wx::_match( @_, $Wx::_wdat_wwin_wcur_wcur_wcur, 1, 1 ) && return $this->newCursorData( @_ );
+  }
+
   croak Wx::_ovl_error;
 }
 
