@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        ext/filesys/lib/Wx/FS.pm
+## Name:        FS.pm
 ## Purpose:     Wx::FS ( pulls in all Wx::FileSystem stuff )
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     28/04/2001
-## RCS-ID:      $Id: FS.pm,v 1.8.2.2 2005/08/16 20:56:32 mbarbon Exp $
-## Copyright:   (c) 2001-2002, 2004-2005 Mattia Barbon
+## Created:     28/ 4/2001
+## RCS-ID:      
+## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -15,11 +15,15 @@ package Wx::FS;
 use Wx;
 use strict;
 
-use vars qw($VERSION);
+require DynaLoader;
+
+use vars qw(@ISA $VERSION);
 
 $VERSION = '0.01';
 
-Wx::wx_boot( 'Wx::FS', $VERSION );
+@ISA = qw(DynaLoader);
+
+bootstrap Wx::FS;
 
 #
 # properly setup inheritance tree
@@ -30,8 +34,6 @@ no strict;
 package Wx::FileSystemHandler;
 package Wx::InternetFSHandler;  @ISA = qw(Wx::FileSystemHandler);
 package Wx::ZipFSHandler;       @ISA = qw(Wx::FileSystemHandler);
-package Wx::PlFileSystemHandler; @ISA = qw(Wx::FileSystemHandler);
-package Wx::PlFSFile;           @ISA = qw(Wx::FSFile);
 
 use strict;
 
