@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        ext/grid/lib/Wx/Grid.pm
-## Purpose:     Wx::Grid (pulls in all Wx::Grid* stuff)
+## Name:        Grid.pm
+## Purpose:     Wx::Grid ( pulls in all Wx::Grid* stuff )
 ## Author:      Mattia Barbon
 ## Modified by:
-## Created:     04/12/2001
-## RCS-ID:      $Id: Grid.pm,v 1.16 2005/11/01 22:16:04 mbarbon Exp $
-## Copyright:   (c) 2001-2002, 2004 Mattia Barbon
+## Created:      4/12/2001
+## RCS-ID:      
+## Copyright:   (c) 2001 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -15,12 +15,14 @@ package Wx::Grid;
 use Wx;
 use strict;
 
-use vars qw($VERSION);
+require DynaLoader;
+
+use vars qw(@ISA $VERSION);
 
 $VERSION = '0.01';
+@ISA = qw(DynaLoader);
 
-Wx::load_dll( 'adv' );
-Wx::wx_boot( 'Wx::Grid', $VERSION );
+bootstrap Wx::Grid;
 
 #
 # properly setup inheritance tree
@@ -29,7 +31,6 @@ Wx::wx_boot( 'Wx::Grid', $VERSION );
 no strict;
 
 package Wx::Grid; @ISA = qw(Wx::ScrolledWindow);
-package Wx::GridWindow; @ISA = qw(Wx::Grid);
 package Wx::GridEvent; @ISA = qw(Wx::NotifyEvent);
 package Wx::GridSizeEvent; @ISA = qw(Wx::NotifyEvent);
 package Wx::GridRangeSelectEvent; @ISA = qw(Wx::NotifyEvent);
@@ -43,20 +44,16 @@ package Wx::GridCellBoolRenderer; @ISA = qw(Wx::GridCellRenderer);
 package Wx::PlGridCellRenderer; @ISA = qw(Wx::GridCellRenderer);
 
 package Wx::GridCellEditor;
-package Wx::GridCellEditorEvtHandler; @ISA = qw(Wx::EvtHandler);
 package Wx::GridCellBoolEditor; @ISA = qw(Wx::GridCellEditor);
 package Wx::GridCellTextEditor; @ISA = qw(Wx::GridCellEditor);
 package Wx::GridCellFloatEditor; @ISA = qw(Wx::GridCellEditor);
 package Wx::GridCellNumberEditor; @ISA = qw(Wx::GridCellEditor);
 package Wx::GridCellChoiceEditor; @ISA = qw(Wx::GridCellEditor);
-package Wx::PlGridCellEditor; @ISA = qw(Wx::GridCellEditor);
-
-package Wx::GridTableBase;
-package Wx::PlGridTable; @ISA = qw(Wx::GridTableBase);
 
 package Wx::Grid;
 
 use strict;
+use Carp;
 
 # this is for make_ovl_list to find constants
 sub CellToRect {
@@ -64,7 +61,7 @@ sub CellToRect {
 
   Wx::_match( @_, $Wx::_wgco, 1 ) && return $this->CellToRectCo( @_ );
   Wx::_match( @_, $Wx::_n_n, 2 )  && return $this->CellToRectXY( @_ );
-  Wx::_croak Wx::_ovl_error;
+  croak Wx::_ovl_error;
 }
 
 sub _create_ovls {
@@ -78,32 +75,24 @@ sub _create_ovls {
 sub ${name} {
   my \$this = shift;
 
-  Wx::_match( \@_, \$Wx::_wgco, 1 ) && return \$this->${name}Co( \@_ );
-  Wx::_match( \@_, \$Wx::_n_n, 2 )  && return \$this->${name}XY( \@_ );
-  Wx::_croak Wx::_ovl_error;
+  Wx::_match( \@_, \$Wx::_wgco, 1 ) && return \$this->${name}Co( @_ );
+  Wx::_match( \@_, \$Wx::_n_n, 2 )  && return \$this->${name}XY( @_ );
+  croak Wx::_ovl_error;
 }
 EOT
 
   die $@ if $@;
 }
 
-# for copytex.pl
-#!sub GetCellValue
-#!sub IsInSelection
-#!sub IsVisible
-#!sub MakeCellVisible
-#!sub GetDefaultEditorForCell
-
 foreach my $i ( qw(GetCellValue IsInSelection IsVisible MakeCellVisible
-                   GetDefaultEditorForCell) )
-  { _create_ovls( $i ); }
+                   ) ) { _create_ovls( $i ); }
 
 sub SelectBlock {
   my $this = shift;
 
   Wx::_match( @_, $Wx::_wgco_wgco_b, 3 ) && return $this->SelectBlockPP( @_ );
   Wx::_match( @_, $Wx::_n_n_n_n_b, 5 )  && return $this->SelectBlockXYWH( @_ );
-  Wx::_croak Wx::_ovl_error;
+  croak Wx::_ovl_error;
 }
 
 sub SetCellValue {
@@ -111,7 +100,7 @@ sub SetCellValue {
 
   Wx::_match( @_, $Wx::_wgco_s, 2 ) && return $this->SetCellValueCo( @_ );
   Wx::_match( @_, $Wx::_n_n_s, 3 )  && return $this->SetCellValueXY( @_ );
-  Wx::_croak Wx::_ovl_error;
+  croak Wx::_ovl_error;
 }
 
 1;
