@@ -24,8 +24,6 @@ FD_TD( HtmlCell );
 FD_TD( HtmlHelpController );
 FD_TD( BestHelpController );
 FD_TD( HtmlEasyPrinting );
-// do not need to depend upon Wx::Config
-FD_TD( ConfigBase );
 // do not need to depend upon Wx::Print
 FD_TD( PrintData );
 FD_TD( PageSetupDialogData );
