@@ -1,11 +1,11 @@
 #############################################################################
-## Name:        lib/Wx/RadioBox.pm
+## Name:        RadioBox.pm
 ## Purpose:     Wx::RadioBox class
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     28/10/2000
-## RCS-ID:      $Id: RadioBox.pm,v 1.9 2004/10/19 20:28:12 mbarbon Exp $
-## Copyright:   (c) 2000-2002 Mattia Barbon
+## RCS-ID:      
+## Copyright:   (c) 2000 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -13,37 +13,45 @@
 package Wx::RadioBox;
 
 use strict;
+use Carp;
+
+if( $Wx::_platform == $Wx::_gtk ) {
+  @Wx::RadioBox::ISA = qw(Wx::Control);
+}
+else {
+  @Wx::RadioBox::ISA = qw(Wx::ControlWithItems);
+}
 
 sub Enable {
   my( $this ) = shift;
 
   Wx::_match( @_, $Wx::_b, 1 )   && ( $this->SUPER::Enable( @_ ), return );
   Wx::_match( @_, $Wx::_n_b, 2 ) && ( $this->EnableItem( @_ ), return );
-  Wx::_croak Wx::_ovl_error;
+  croak Wx::_ovl_error;
 }
 
 sub GetLabel {
   my( $this ) = shift;
 
   @_ == 0                  && return $this->SUPER::GetLabel();
-  Wx::_match( @_, $Wx::_n, 1 ) && return $this->GetItemLabel( @_ );
-  Wx::_croak Wx::_ovl_error;
+  Wx::_match( @_, $Wx::_n, 1 ) && return $this->GetItemLabel();
+  croak Wx::_ovl_error;
 }
 
 sub SetLabel {
   my( $this ) = shift;
 
-  Wx::_match( @_, $Wx::_s, 1 )   && ( $this->SUPER::SetLabel( @_ ), return );
-  Wx::_match( @_, $Wx::_n_s, 2 ) && ( $this->SetItemLabel( @_ ), return );
-  Wx::_croak Wx::_ovl_error;
+  Wx::_match( @_, $Wx::_n_s, 2 ) && $this->SetItemLabel( @_ );
+  Wx::_match( @_, $Wx::_s, 1 )   && $this->SUPER::SetLabel( @_ );
+  croak Wx::_ovl_error;
 }
 
 sub Show {
   my( $this ) = shift;
 
-  Wx::_match( @_, $Wx::_n, 1 )   && ( $this->SUPER::Show( @_ ), return );
-  Wx::_match( @_, $Wx::_n_n, 2 ) && ( $this->ShowItem( @_ ), return );
-  Wx::_croak Wx::_ovl_error;
+  Wx::_match( @_, $Wx::_n_n, 2 ) && $this->ShowItem( @_ );
+  Wx::_match( @_, $Wx::_n, 1 )   && $this->Show( @_ );
+  croak Wx::_ovl_error;
 }
 
 1;
